==> AATKit-3.2.0-sources.jar: com/intentsoftware/addapptr/MultiSizeBannerPlacement.kt <==
package com.intentsoftware.addapptr

import com.intentsoftware.addapptr.AATKit.setTargetingInfo

/**
 * Placement used for obtaining banner ads.
 */
@Suppress("unused")
interface MultiSizeBannerPlacement : Placement {
    /**
     * Set the [placement listener][MultiSizeBannerPlacementListener] that will listen to ad loading and display events.
     */
    var listener: MultiSizeBannerPlacementListener?

    /**
     * Sets the [statistics listener][AATKit.StatisticsListener] that will be notified about placement reporting events, like counted adspace, request etc.
     */
    var statisticsListener: AATKit.StatisticsListener?

    /**
     * Sets the [impression listener][ImpressionListener] for the given placement.
     */
    var impressionListener: ImpressionListener?

    /**
     * Enables automatic reloading of placement. Autoreloader will use reload time configured on addapptr.com account or fallback to default {@value #BANNER_DEFAULT_RELOAD_INTERVAL_IN_SECONDS} seconds.
     */
    fun startAutoReload()

    /**
     * Enables automatic reloading of placement and sets custom reload time. This reload time will be used instead of time configured on addapptr.com account.
     *
     * @param seconds     Interval between ad reloads. Should be a value from
     * 30
     * up to
     * 600 seconds.
     */
    fun startAutoReload(seconds: Int)

    /**
     * Disables automatic reloading of placement.
     */
    fun stopAutoReload()

    /**
     * Sets reload time that will be used instead of time configured on addapptr.com account.
     *
     * @param seconds     Interval between ad reloads. Should be a value from {@value #BANNER_MIN_RELOAD_INTERVAL_IN_SECONDS} to {@value #BANNER_MAX_RELOAD_INTERVAL_IN_SECONDS} seconds.
     */
    fun setAutoreloadInterval(seconds: Int)

    /**
     * Requests placement reload. Works only if automatic reloading is disabled.
     *
     * @return True if call ends in causing a placement to reload, false otherwise.
     */
    fun reload(): Boolean

    /**
     * Requests placement reload. Works only if automatic reloading is disabled.
     *
     * @param force   True if you want to be able to reload and show new banner before set banner reload interval (default: 30s) between reloads, false otherwise.
     * @return True if call ends in causing a placement to reload, false otherwise.
     */
    fun reload(force: Boolean): Boolean

    /**
     * Returns true if there is an ad loaded for given placementId.
     *
     * @return True if there is an ad loaded for given placementId.
     */
    fun hasAd(): Boolean

    /**
     * Sets the targeting information for the given placement. Information provided for placement overrides targeting information for application set by the [setTargetingInfo].
     */
    var targetingInfo: Map<String, List<String>>?

    /**
     * Sets the content targeting url for the application. This information will be used only if no placement-specific targeting is available.
     *
     * @see .setContentTargetingUrl
     */
    var contentTargetingUrl: String?
}

==> AATKit-3.13.2-sources.jar: com/intentsoftware/addapptr/MultiSizeBannerPlacement.kt <==
package com.intentsoftware.addapptr

import com.intentsoftware.addapptr.AATKit.setTargetingInfo
import com.intentsoftware.addapptr.internal.module.PlacementHistoryInfo

/**
 * Placement used for obtaining banner ads.
 */
@Suppress("unused")
interface MultiSizeBannerPlacement : Placement {
    /**
     * Set the [placement listener][MultiSizeBannerPlacementListener] that will listen to ad loading and display events.
     */
    var listener: MultiSizeBannerPlacementListener?

    /**
     * Sets the [statistics listener][AATKit.StatisticsListener] that will be notified about placement reporting events, like counted adspace, request etc.
     */
    var statisticsListener: AATKit.StatisticsListener?

    /**
     * Sets the [impression listener][ImpressionListener] for the given placement.
     */
    var impressionListener: ImpressionListener?

    /**
     * Setting for Google collapsible banners. Default is null, meaning disabled support for collapsible banners.
     */
    var collapsibleBannerOptions: CollapsibleBannerOptions?

    /**
     * Enables automatic reloading of placement. Autoreloader will use reload time configured on addapptr.com account or fallback to default {@value #BANNER_DEFAULT_RELOAD_INTERVAL_IN_SECONDS} seconds.
     */
    fun startAutoReload()

    /**
     * Enables automatic reloading of placement and sets custom reload time. This reload time will be used instead of time configured on addapptr.com account.
     *
     * @param seconds     Interval between ad reloads. Should be a value from
     * 30
     * up to
     * 600 seconds.
     */
    fun startAutoReload(seconds: Int)

    /**
     * Disables automatic reloading of placement.
     */
    fun stopAutoReload()

    /**
     * Sets reload time that will be used instead of time configured on addapptr.com account.
     *
     * @param seconds     Interval between ad reloads. Should be a value from {@value #BANNER_MIN_RELOAD_INTERVAL_IN_SECONDS} to {@value #BANNER_MAX_RELOAD_INTERVAL_IN_SECONDS} seconds.
     */
    fun setAutoreloadInterval(seconds: Int)

    /**
     * Requests placement reload. Works only if automatic reloading is disabled.
     *
     * @return True if call ends in causing a placement to reload, false otherwise.
     */
    fun reload(): Boolean

    /**
     * Requests placement reload. Works only if automatic reloading is disabled.
     *
     * @param force   True if you want to be able to reload and show new banner before set banner reload interval (default: 30s) between reloads, false otherwise.
     * @return True if call ends in causing a placement to reload, false otherwise.
     */
    fun reload(force: Boolean): Boolean

    /**
     * Returns true if there is an ad loaded for given placementId.
     *
     * @return True if there is an ad loaded for given placementId.
     */
    fun hasAd(): Boolean

    /**
     * Sets the targeting information for the given placement. Information provided for placement overrides targeting information for application set by the [setTargetingInfo].
     */
    var targetingInfo: Map<String, List<String>>?

    /**
     * Sets the content targeting url for the application. This information will be used only if no placement-specific targeting is available.
     *
     * @see .setContentTargetingUrl
     */
    var contentTargetingUrl: String?

    /**
     * Sets the multi content targeting url for the application. Not all ad-networks supports multiple urls.
     */
    var multiContentTargetingUrls: List<String>?


    /**
     * Enables the banner creative history.
     */
    fun enableCreativeHistory(size: Int)

    /**
     * Retrieves the banner creative history (if it was enabled).
     */
    fun getCreativeHistory(): Array<PlacementHistoryInfo>?
}
